==> apache-doris-2.0.15.1-src.tar.gz: apache-doris-2.0.15.1-src/docs/en/community/join-community.md <==
---
{
    "title": "Join Community",
    "language": "en"
}

---

<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->


**Thrive together in [Apache Doris](https://github.com/apache/doris) community with users and developers from all around the world.** 
We have graduated from Apache incubator succesffully and become an Top-Level Project in June 2022.

<hr />

## 🙌 More Developers Join Us
[![Monthly Active Contributors](https://contributor-overtime-api.apiseven.com/contributors-svg?chart=contributorMonthlyActivity&repo=apache/doris)](https://www.apiseven.com/en/contributor-graph?chart=contributorMonthlyActivity&repo=apache/doris)













[![Contributor over time](https://contributor-overtime-api.apiseven.com/contributors-svg?chart=contributorOverTime&repo=apache/doris)](https://www.apiseven.com/en/contributor-graph?chart=contributorOverTime&repo=apache/doris)

















## 🌟 More Stars on Github
<a href="https://star-history.com/#apache/doris&Date">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://api.star-history.com/svg?repos=apache/doris&type=Date&theme=dark" />
    <source media="(prefers-color-scheme: light)" srcset="https://api.star-history.com/svg?repos=apache/doris&type=Date" />
    <img alt="Star History Chart" src="https://api.star-history.com/svg?repos=apache/doris&type=Date" />
  </picture>
</a>















##### We deeply appreciate 🔗[community contributors](https://github.com/apache/doris/graphs/contributors) for their contribution to Apache Doris.




<hr />

# Don't Miss Out the Latest News and Events

Learn our latest techniques, get inspirations from our rich use cases, and see what the community has been up to !


- ### Join our heated discussions -  💬 [Slack](https://join.slack.com/t/apachedoriscommunity/shared_invite/zt-1x7x8fger-F7NoshFQn~djlvGdnEtxUQ) 📇 [Github](https://github.com/apache/doris) 

- ### Use cases and tech insight -  📭 [Twitter](https://twitter.com/doris_apache) 

- ### Come and connect with us - 🌐 [LinkedIn](https://www.linkedin.com/company/doris-apache/) 

- ### Events Videos - ▶️ [YouTube](https://www.youtube.com/@Select_DB) 📺 [Bilibili](https://space.bilibili.com/362350065)

==> apache-doris-2.1.11-rc01-src.tar.gz: apache-doris-2.1.11-rc01-src/docs/en/community/join-community.md <==
---
{
    "title": "Join Community",
    "language": "en"
}

---

<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->


**Thrive together in [Apache Doris](https://github.com/apache/doris) community with users and developers from all around the world.** 
We have graduated from Apache incubator successfully and become an Top-Level Project in June 2022.

<hr />

## 🙌 More Developers Join Us
[![Monthly Active Contributors](https://contributor-overtime-api.apiseven.com/contributors-svg?chart=contributorMonthlyActivity&repo=apache/doris)](https://www.apiseven.com/en/contributor-graph?chart=contributorMonthlyActivity&repo=apache/doris)













[![Contributor over time](https://contributor-overtime-api.apiseven.com/contributors-svg?chart=contributorOverTime&repo=apache/doris)](https://www.apiseven.com/en/contributor-graph?chart=contributorOverTime&repo=apache/doris)

















## 🌟 More Stars on Github
<a href="https://star-history.com/#apache/doris&Date">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://api.star-history.com/svg?repos=apache/doris&type=Date&theme=dark" />
    <source media="(prefers-color-scheme: light)" srcset="https://api.star-history.com/svg?repos=apache/doris&type=Date" />
    <img alt="Star History Chart" src="https://api.star-history.com/svg?repos=apache/doris&type=Date" />
  </picture>
</a>















##### We deeply appreciate 🔗[community contributors](https://github.com/apache/doris/graphs/contributors) for their contribution to Apache Doris.




<hr />

# Don't Miss Out the Latest News and Events

Learn our latest techniques, get inspirations from our rich use cases, and see what the community has been up to !


- ### Join our heated discussions -  💬 [Slack](https://join.slack.com/t/apachedoriscommunity/shared_invite/zt-1x7x8fger-F7NoshFQn~djlvGdnEtxUQ) 📇 [Github](https://github.com/apache/doris) 

- ### Use cases and tech insight -  📭 [Twitter](https://twitter.com/doris_apache) 

- ### Come and connect with us - 🌐 [LinkedIn](https://www.linkedin.com/company/doris-apache/) 

- ### Events Videos - ▶️ [YouTube](https://www.youtube.com/@Select_DB) 📺 [Bilibili](https://space.bilibili.com/362350065)
